// ==UserScript==
// @name ClanGloryPoints
// @namespace http://forum.worldoftanks.ru/index.php?/topic/1083013-
// @description Adds glory points on clan page
// @author chuuddo
// @license GPL v3 or any later version; http://www.gnu.org/copyleft/gpl.html
// @version 0.8.9.3
// @include /^http:\/\/worldoftanks.ru\/(community|uc)\/clans\/\d+(|-|-\w+)\/$/
// @require http://cdn.jsdelivr.net/tablesorter/2.13.3/js/jquery.tablesorter.min.js
// @require http://cdn.jsdelivr.net/tablesorter/2.13.3/js/jquery.tablesorter.widgets.min.js
// ==/UserScript==
(function (window) {
    if (/^\/(community|uc)\/clans\/\d+(|-|-\w+)\/$/.test(window.location.pathname)) {
        $.tablesorter.addParser({
            id: "dd.mm.yyyy",
            is: function (s) { return false; },
            format: function (s) {
                var hit = ("" + s).match(/(\d{1,2})\.(\d{1,2})\.(\d{4})/);
                return hit && hit.length == 4 ? hit[3] + hit[2] + hit[1] : s;
            },
            type: "text"
        });
        $.tablesorter.addParser({
            id: "role",
            is: function (s) { return false; },
            format: function (s) {
                var roles = { 0: "Новобранец", 1: "Солдат", 2: "Казначей", 3: "Дипломат", 4: "Вербовщик", 5: "Ротный командир", 6: "Заместитель командира", 7: "Командир" };
                for (var key in roles) {
                    s = s.replace(roles[key], key)
                }
                return s;
            },
            type: "numeric"
        });
        $.tablesorter.addWidget({
            id: "numbering",
            format: function (table) {
                $("tr", table.tBodies[0]).each(function (i) {
                    $(this).find("td").eq(0).text(i + 1);
                });
            }
        });
        
        $("#clans_info_content").before("<div id=\"load_glory_button\" style=\"float: right; margin-bottom: 5px;\"></div><div style=\"clear:both\"></div>"); 
        $(document).ajaxStop(function () {
            $("#load_glory_button").html("<span class=\"b-button b-button__colored\"><span class=\"b-button_right b-button-wrap\"><input type=\"submit\" value=\"Загрузить очки славы\"></span></span>");
            $("#load_glory_button input").click(function(){
                Main();
            }); 
        });
        
        function Main(){
            var style = document.createElement("style");
            style.type = "text/css";
            style.appendChild(document.createTextNode(
                ".tablesorter-header-inner{ margin-left: 0px; margin-right: 0px; padding-left: 0px; text-align:center; }" +
                ".green {color: #60FF00 !important; }" +
                ".red {color: #FE0E00 !important;}" +
                ".t-table tr td:nth-child(n+3){text-align: center;}"));
            document.head.appendChild(style);
            
            $(".t-table").hide();
            $("#clans_info_content").append("<div class=\"loading\" align=\"center\"><img src=\"/static/3.11.1.2/common/css/block/b-content/img/waiting.gif\"><br /><br /><div class=\"progress\">0%</div></div>");
            if($(".t-table thead th").length == 6){
                $(".t-table tbody tr td:nth-child(n+5)").remove();
            } else {
                $(".t-table tbody tr:first").remove();
                $(".t-table thead span").removeAttr("onclick");
                $(".t-table thead span i").remove();
                $(".t-table div[id^=\"js-checkbox\"]").parent().remove();
                $(".t-table tbody tr").removeClass("odd even");
                $(".t-table thead tr").append("<th><span class=\"b-sort-box\">Очки славы</span></th><th><span class=\"b-sort-box\">Позиция</span></th>");
                $(".t-table").tablesorter({
                    cssDesc: "ordered desc",
                    cssAsc: "ordered asc",
                    sortList: [[5,0]],
                    headers: {
                        0: { sorter: false },
                        2: { sorter: "role" },
                        3: { sorter: "dd.mm.yyyy" }
                    },
                    widgets: ["numbering"],
                });
            }
            
            var members = $(".t-table tbody tr").length;
            var i = 0;
            $(".t-table tbody tr").each(function (index, element) {
                $.ajax({
                    type: "GET",
                    url: "/community/clans/show_clan_block/",
                    data: { spa_id: /\/(\d+)-/g.exec($(element).find(":nth-child(2) a").attr("href"))[1] },
                    dataType: "json",
                    timeout: 15000,
                    success: function (response) {
                        AddGlory(response, "success", element)
                    },
                    error: function (response) {
                        AddGlory(response, "error", element)
                    }
                });
            });
            function AddGlory(response, type, element){
                i++;
                var progress = (i/members*100).toFixed(0);
                $(".progress").text(progress+"%");
                if(type === "success") {
                    var position = $(response.data.glory_points_block).find("#js-glory-points").text();
                    var points = $(response.data.glory_points_block).find("#js-glory-points_tooltip p").text().replace(/\s/g, "").split(":")[1];
                    var glory_points = /\d+/.test(points) ? points : "0";
                    var glory_position = position != "" ? position.replace(/\s/g, "") : "-";
                    var color = glory_position <= 30000 ? "green" : "red";
                    $(element).append("<td class=" + color + ">" + glory_points + "</td><td class=" + color + ">" + glory_position + "</td>");
                }
                if(type === "error") {
                    $(element).append("<td class=\"red\">error</td><td class=\"red\">error</td>");
                }
                if(progress == 100){
                    showTable();
                }
            }
            function showTable () {
                $(".t-table").trigger("update");
                $(".t-table").trigger("sorton", [[[5,0]]]);
                $(".loading").remove();
                $(".t-table").show();
            }
        }
    }
})(window);